@@ -1,5 +1,5 @@
 from .auth import (BearerAuth, OAuth2AuthorizationCodeAuth,
-                   OAuth2ClientCredentialsAuth, OAuth20AccessAndRefreshTokenAuth)
+                   OAuth2ClientCredentialsAuth, OAuth20AccessTokenAuth)
 from .authorization_code import AuthorizationCodeHandler
 from .client import OAuth2Client
 from .client_authentication import (ClientSecretBasic, ClientSecretJWT,
